@@ -46,7 +46,7 @@ char *progname = "Dali Clock";   // digital.c wants this for error messages.
   NSDictionary* defaults = [NSDictionary dictionaryWithObjectsAndKeys:
     @"NO", @"windowTitlebarIsHidden",
     @"NO", @"dockIconIsHidden",
-    @"2", @"windowLevel",
+    @"0", @"windowLevel",  // default to "normal window"
     nil];
 
   NSMutableDictionary *dict = [NSMutableDictionary dictionaryWithCapacity:100];
@@ -57,6 +57,17 @@ char *progname = "Dali Clock";   // digital.c wants this for error messages.
 }
 
 
+// Convert preferences radio button value to real window level.
+static int
+real_window_level(int pref) {
+  return (pref == 0 ? NSNormalWindowLevel        :  // normal
+          pref == 1 ? NSNormalWindowLevel-1      :  // below all
+          pref == 2 ? NSFloatingWindowLevel      :  // above all
+//        pref == 3 ? NSScreenSaverWindowLevel+1 :  // above saver
+          pref == 3 ? CGShieldingWindowLevel()   :  // above saver
+          NSNormalWindowLevel);                     // unknown
+}
+
 - (void)createDaliClockWindow;
 {
   NSUserDefaults *prefs = [NSUserDefaults standardUserDefaults];
@@ -64,10 +75,7 @@ char *progname = "Dali Clock";   // digital.c wants this for error messages.
   BOOL title_p = ![prefs boolForKey:@"windowTitlebarIsHidden"];
   BOOL was_fullscreen_p = (fullscreen_window_level != 0);
 
-  int level = [prefs integerForKey:@"windowLevel"];
-  level = (level == 0 ? NSFloatingWindowLevel :
-           level == 1 ? NSNormalWindowLevel-1 :
-           NSNormalWindowLevel);
+  int level = real_window_level ([prefs integerForKey:@"windowLevel"]);
 
   if (was_fullscreen_p) {
     [NSCursor unhide];
@@ -182,11 +190,11 @@ char *progname = "Dali Clock";   // digital.c wants this for error messages.
 
   [userDefaultsController addObserver:self
                            forKeyPath:@"values.windowLevel"
-                              options:nil
+                              options:0
                               context:@selector(windowLevelDidChange:)];
   [userDefaultsController addObserver:self
                            forKeyPath:@"values.windowTitlebarIsHidden"
-                              options:nil
+                              options:0
                          context:@selector(windowTitlebarIsHiddenDidChange:)];
 
   [window makeKeyAndOrderFront:self];
@@ -226,10 +234,7 @@ char *progname = "Dali Clock";   // digital.c wants this for error messages.
 - (void)windowLevelDidChange:(NSDictionary *)change
 {
   NSUserDefaults *prefs = [NSUserDefaults standardUserDefaults];
-  int level = [prefs integerForKey:@"windowLevel"];
-  level = (level == 0 ? NSFloatingWindowLevel :
-           level == 1 ? NSNormalWindowLevel-1 :
-           NSNormalWindowLevel);
+  int level = real_window_level ([prefs integerForKey:@"windowLevel"]);
   [window setLevel:level];
 }
 
